'use strict';

var pluginScaffolderNode = require('@backstage/plugin-scaffolder-node');
var sendNotification_examples = require('./sendNotification.examples.cjs.js');

function createSendNotificationAction(options) {
  const { notifications } = options;
  return pluginScaffolderNode.createTemplateAction({
    id: "notification:send",
    description: "Sends a notification using NotificationService",
    examples: sendNotification_examples.examples,
    schema: {
      input: {
        type: "object",
        required: ["recipients", "title"],
        properties: {
          recipients: {
            title: "Recipient",
            enum: ["broadcast", "entity"],
            description: "The recipient of the notification, either broadcast or entity. If using entity, also entityRef must be provided",
            type: "string"
          },
          entityRefs: {
            title: "Entity references",
            description: "The entity references to send the notification to, required if using recipient of entity",
            type: "array",
            items: {
              type: "string"
            }
          },
          title: {
            title: "Title",
            description: "Notification title",
            type: "string"
          },
          info: {
            title: "Description",
            description: "Notification description",
            type: "string"
          },
          link: {
            title: "Link",
            description: "Notification link",
            type: "string"
          },
          severity: {
            title: "Severity",
            type: "string",
            description: `Notification severity`,
            enum: ["low", "normal", "high", "critical"]
          },
          scope: {
            title: "Scope",
            description: "Notification scope",
            type: "string"
          },
          optional: {
            title: "Optional",
            description: "Do not fail the action if the notification sending fails",
            type: "boolean"
          }
        }
      }
    },
    async handler(ctx) {
      const {
        recipients,
        entityRefs,
        title,
        info,
        link,
        severity,
        scope,
        optional
      } = ctx.input;
      ctx.logger.info(`Sending notification to ${recipients}`);
      if (recipients === "entity" && !entityRefs) {
        if (optional !== true) {
          throw new Error("Entity references must be provided");
        }
        return;
      }
      const notificationRecipients = recipients === "broadcast" ? { } : { };
      const payload = {
        };
      try {
        await notifications.send({
          recipients: notificationRecipients,
          payload
        });
      } catch (e) {
        ctx.logger.error(`Failed to send notification: ${e}`);
        if (optional !== true) {
          throw e;
        }
      }
    }
  });
}

exports.createSendNotificationAction = createSendNotificationAction;
//# sourceMappingURL=sendNotification.cjs.js.map
